.onAttach <- function(libname, pkgname) {
  packageStartupMessage(
    "mqqcause 1.0.0  Multivariate QQ Granger Causality\n",
    "  Default colour scale: MATLAB Parula. See mqqcause_colorscales()."
  )
}
