#' @keywords internal
"_PACKAGE"

#' mqqcause: Multivariate Quantile-on-Quantile Granger Causality
#'
#' Implements bivariate Quantile-on-Quantile Granger causality and the
#' multivariate (conditional) version with a vector of moderators and
#' optional interaction terms. A Sup-Wald summary across the (theta, tau)
#' grid is also provided (Troster, 2018).
#'
#' @docType package
#' @name mqqcause-package
NULL
